Learn R Programming

gbifdb (version 1.0.0)

gbif_dir: Default storage location

Description

Default location can be set with the env var GBIF_HOME, otherwise will use the default provided by tools::R_user_dir()

Usage

gbif_dir()

Arguments

Value

path to the gbif home directory directory

Examples

Run this code
gbif_dir()

Run the code above in your browser using DataLab