powered by
Default location can be set with the env var GBIF_HOME, otherwise will use the default provided by tools::R_user_dir()
tools::R_user_dir()
gbif_dir()
path to the gbif home directory directory
Run the code above in your browser using DataLab